SpecializedBitmap

Trait SpecializedBitmap 

pub trait SpecializedBitmap: OwnedBitmap + AsMut<Bitmap> {
    const BITMAP_KIND: BitmapKind;
}
An owned specialized bitmap (CpuSet or NodeSet)

hwlocality avoids the need for error-prone hwloc-style BYNODESET flags by making CpuSet and NodeSet full-blown types, not typedefs. Functions which want to accept either of these specialized bitmap types can be made generic over this SpecializedBitmap trait, which can be used to query which specialized bitmap type was passed in and then switch to generic Bitmap processing.

See also SpecializedBitmapRef.

Required Associated Constants

const BITMAP_KIND: BitmapKind

Tag used to discriminate between specialized bitmaps in code

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors