pub enum TypeToDepthError {
Nonexistent,
Multiple,
}Expand description
Error from an hwloc query looking for the depth of a certain object type
Variants
Nonexistent
No object of the requested type exists in the topology
Multiple
Objects of the requested type exist at different depths in the topology
At the time of writing, this can only happen with ObjectType::Group.