AllowSetError

Enum AllowSetError 

pub enum AllowSetError {
    EmptyCustom,
    InvalidCpuset,
    InvalidNodeset,
    Unsupported,
}
Available on crate feature hwloc-2_3_0 only.
Error while trying to set the allow-set of a topology

Variants



EmptyCustom

AllowSet::Custom was specified but both the cpuset and nodeset were empty, so it isn’t clear how the allow set should change



InvalidCpuset

AllowSet::Custom was specified with a cpuset that would disallow all CPUs from the topology



InvalidNodeset

AllowSet::Custom was specified with a nodeset that would disallow all NUMA nodes from the topology



Unsupported

An unsupported AllowSet was passed in

At the time of writing (2024-01-08), this happens when using AllowSet::LocalRestrictions on any operating system other than Linux and Solaris.